# Main

> Auto-generated documentation for [demo.main](../../../demo/main.py) module.

- [Src](../README.md#src-index) / [Modules](../MODULES.md#src-modules) / [Demo](index.md#demo) / Main
    - [new_func](#new_func)
    - [sample](#sample)

## new_func

[[find in source code]](../../../demo/main.py#L7)

```python
def new_func():
```

Sample new function

## sample

[[find in source code]](../../../demo/main.py#L2)

```python
def sample():
```

sample Module
